Name:           why3
Version:        0.87.3
Release:        %mkrel 2
Summary:        Software verification platform
Group:          Sciences/Computer science
License:        LGPLv2 with exceptions
URL:            http://why3.lri.fr/
Source0:        https://gforge.inria.fr/frs/download.php/file/36398/%{name}-%{version}.tar.gz
# Man pages written by Jerry James using text found in the sources.  Hence,
# the copyright and license are the same as for the upstream sources.
Source1:        %{name}-man.tar.xz

BuildRequires:  coq
BuildRequires:  coq-flocq
BuildRequires:  frama-c
BuildRequires:  hevea
BuildRequires:  ocaml-compiler
BuildRequires:  camlp5
BuildRequires:  ocaml-findlib-devel
BuildRequires:  ocaml-lablgtk2-devel
BuildRequires:  ocaml-ocamlgraph-devel
BuildRequires:  ocaml-sqlite3-devel
BuildRequires:  rubber
BuildRequires:  emacs
BuildRequires:  ocaml-curses-devel
BuildRequires:  ocaml-zarith-devel
BuildRequires:  ocaml-camlzip-devel
BuildRequires:  menhir
BuildRequires:  ncurses-devel

Requires:       frama-c
Requires:       vim-minimal
Requires:       alt-ergo
Requires:       coq

%description
Why3 is the next generation of the Why software verification platform.
Why3 clearly separates the purely logical specification part from
generation of verification conditions for programs.  It features a rich
library of proof task transformations that can be chained to produce a
suitable input for a large set of theorem provers, including SMT
solvers, TPTP provers, as well as interactive proof assistants.

%package emacs
Summary:        Emacs support file for %{name} files
Group:          Editors
Requires:       %{name} = %{version}-%{release}
Requires:       emacs
BuildArch:      noarch

%description emacs
This package contains an Emacs support file for working with %{name} files.

%package -n ocaml-why3
Summary:    OCaml library for %{name}
Group:      Development/OCaml
Requires:   why3 = %{version}-%{release}
Requires:   ocaml-compiler

%description -n ocaml-why3
The %{name} library is an OCaml library providing access to the why3 program prover.


%package -n ocaml-why3-devel
Summary:    Development files for %{name}
Group:      Development/OCaml
Requires:   ocaml-%{name} = %{version}-%{release}

%description -n ocaml-why3-devel
This package contains the development files needed to build applications
using %{name}.


%prep
%setup -q
%setup -q -T -D -a 1

# Use the correct compiler flags, keep timestamps, and harden the build due to
# network use
sed -e "s|-Wall|%{optflags}|" \
    -e "s/cp /cp -p /" \
    -e "s|^OLINKFLAGS =.*|& -ccopt \"%{ldflags}\"|" \
    -i Makefile.in

# Remove spurious executable bits
find -O3 examples -type f -perm /0111 | xargs chmod a-x

%build
%configure2_5x --enable-frama-c --enable-verbose-make
make
make byte

%install
make install install_no_local_lib \
     DESTDIR=%{buildroot} \
     OCAMLINSTALLLIB=%{buildroot}%{_libdir}/ocaml

# Install the man pages
mkdir -p %{buildroot}%{_mandir}/man1
pushd man
for f in *.1; do
  sed "s/@version@/%{version}/" $f > %{buildroot}%{_mandir}/man1/$f
  touch -r $f %{buildroot}%{_mandir}/man1/$f
done
popd

# Install the bash completion file
mkdir -p %{buildroot}%{_datadir}/bash-completion/completions
cp -p share/bash/%{name} %{buildroot}%{_datadir}/bash-completion/completions

# Install the zsh completion file
mkdir -p %{buildroot}%{_datadir}/zsh/site-functions
cp -p share/zsh/_why3 %{buildroot}%{_datadir}/zsh/site-functions

# Install the LaTeX style
mkdir -p %{buildroot}%{_datadir}/texmf/tex/latex/%{name}
cp -p share/latex/why3lang.sty %{buildroot}%{_datadir}/texmf/tex/latex/%{name}/

# Move the gtksourceview language file to the right place
mkdir -p %{buildroot}%{_datadir}/gtksourceview-2.0/language-specs/
mv %{buildroot}%{_datadir}/%{name}/lang/why3.lang \
   %{buildroot}%{_datadir}/gtksourceview-2.0/language-specs

# Move the vim file to the right place
mkdir -p %{buildroot}%{_datadir}/vim/vimfiles
mv %{buildroot}%{_datadir}/%{name}/vim \
   %{buildroot}%{_datadir}/vim/vimfiles/syntax

# Byte compile emacs support.
pushd %{buildroot}%{_emacs_sitelispdir}
%{_emacs_bytecompile} %{name}.el
popd

# Remove misplaced documentation
rm -fr %{buildroot}%{_datadir}/doc

# fix ocaml lib files
rm -f %{buildroot}%{_libdir}/ocaml/why3/why3.o
rm -f %{buildroot}%{_libdir}/ocaml/why3/why3.cmo
rm -f %{buildroot}%{_libdir}/ocaml/why3/why3extract.o
rm -f %{buildroot}%{_libdir}/ocaml/why3/why3extract.cmo
cp lib/why3/why3.ml %{buildroot}%{_libdir}/ocaml/why3/

%files
%doc AUTHORS CHANGES LICENSE README doc/manual.pdf
%{_bindir}/%{name}*
%{_datadir}/%{name}/
%{_datadir}/bash-completion/completions/why3
%{_datadir}/gtksourceview-2.0/language-specs/%{name}.lang
%{_datadir}/vim/vimfiles/syntax/%{name}.vim
%{_datadir}/zsh/site-functions/_why3
%{_datadir}/texmf/tex/latex/%{name}/
#{_libdir}/frama-c/plugins/Jessie3.*
%{_libdir}/%{name}
%{_mandir}/man1/%{name}*

%files -n ocaml-why3
%dir %{_libdir}/ocaml/why3
%{_libdir}/ocaml/why3/why3.cmi
%{_libdir}/ocaml/why3/why3.cma
%{_libdir}/ocaml/why3/META
%{_libdir}/ocaml/why3/why3extract.cma
%{_libdir}/ocaml/why3/why3extract.cmi

%files -n ocaml-why3-devel
%{_libdir}/ocaml/why3/why3.a
%{_libdir}/ocaml/why3/why3.cmxa
%{_libdir}/ocaml/why3/why3.cmx
%{_libdir}/ocaml/why3/why3.ml
%{_libdir}/ocaml/why3/why3extract.a
%{_libdir}/ocaml/why3/why3extract.cmx
%{_libdir}/ocaml/why3/why3extract.cmxa

%files emacs
%{_emacs_sitelispdir}/%{name}.elc
%{_emacs_sitelispdir}/%{name}.el


%changelog
* Sat Jan 21 2017 daviddavid <daviddavid> 0.87.3-2.mga6
+ Revision: 1082701
- move the vim file to the right place
- package the LaTeX style file
- sync the compiler flags with fedora's one
- enable verbose make
- use emacs macros

* Sat Jan 21 2017 daviddavid <daviddavid> 0.87.3-1.mga6
+ Revision: 1082667
- new version: 0.87.3

* Mon Sep 26 2016 pterjan <pterjan> 0.87.2-2.mga6
+ Revision: 1056527
- Rebuild for fix in ocaml

* Sun Sep 18 2016 daviddavid <daviddavid> 0.87.2-1.mga6
+ Revision: 1053745
- new version: 0.87.2

* Sat Mar 26 2016 daviddavid <daviddavid> 0.87.0-1.mga6
+ Revision: 995574
- new version: 0.87.0

* Wed Feb 17 2016 daviddavid <daviddavid> 0.86.3-1.mga6
+ Revision: 963749
- new version: 0.86.3
- update Source URL
- add BR on menhir
- update files list

  + umeabot <umeabot>
    - Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 0.84-3.mga5
+ Revision: 749339
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.84-2.mga5
+ Revision: 690308
- Mageia 5 Mass Rebuild

* Tue Sep 09 2014 malo <malo> 0.84-1.mga5
+ Revision: 673886
- adding missing BR
- fix install files
- dropped upstreamed patches
- update to 0.84

* Tue Dec 03 2013 malo <malo> 0.81-2.mga4
+ Revision: 554767
- add ocaml library

* Mon Dec 02 2013 malo <malo> 0.81-1.mga4
+ Revision: 554585
- spec clean-up after import from Fedora
- imported package why3


* Mon Sep 30 2013 Jerry James <loganjerry@gmail.com> - 0.81-6
- Apply upstream fix for change in the alt-ergo timelimit option

* Tue Sep 17 2013 Jerry James <loganjerry@gmail.com> - 0.81-5
- Rebuild for OCaml 4.01.0
- Enable debuginfo for the ocaml sources

* Sun Aug 04 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.81-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Fri Jun 21 2013 Jerry James <loganjerry@gmail.com> - 0.81-3
- Rebuild for frama-c Fluorine 20130601

* Thu May 23 2013 Jerry James <loganjerry@gmail.com> - 0.81-2
- Rebuild for frama-c Fluorine 20130501

* Fri May 10 2013 Jerry James <loganjerry@gmail.com> - 0.81-1
- New upstream release
- Disable PVS support for now; it requires the NASA libraries
- Fix the conflict between the why and why3 Emacs packages (bz 913522)
- Disable parallel builds due to intermittent build failures

* Fri Feb 15 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.73-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Mon Jan  7 2013 Jerry James <loganjerry@gmail.com> - 0.73-4
- Rebuild for coq 8.4pl1

* Fri Dec 14 2012 Richard W.M. Jones <rjones@redhat.com> - 0.73-3
- Rebuild for OCaml 4.00.1.

* Thu Aug 23 2012 Jerry James <loganjerry@gmail.com> - 0.73-2
- Rebuild for coq 8.4

* Thu Aug  2 2012 Jerry James <loganjerry@gmail.com> - 0.73-1
- New upstream release

* Sun Jul 22 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.71-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Thu Apr 19 2012 Jerry James <loganjerry@gmail.com> - 0.71-2
- Add missing sqlite-devel BR
- Do not move the coq plugin
- Generate debuginfo for the sole C program
- Add man pages

* Fri Dec 16 2011 Jerry James <loganjerry@gmail.com> - 0.71-1
- Initial RPM
